==> scanbot_sdk-2.9.0.tar.gz: lib/classical_components/classical_camera.dart <==
import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:scanbot_sdk/common_data.dart' as c;

import 'camera_configuration.dart';
import 'finder.dart';
import 'live_detection.dart';

class ScanbotCamera extends StatefulWidget {
  final CameraConfiguration configuration;

  final LiveDetector? detector;

  /// triggers when camera plugin make long work eg. saving snap to the image etc.
  final Function(bool)? onHeavyOperationProcessing;

  /// returns page after sucessfull snap
  final Function(c.Page)? onPictureTaken;

  final Function(ScanbotCameraController) onCameraReady;

  final FinderConfiguration? finder;

  const ScanbotCamera(
      {Key? key,
      required this.configuration,
      required this.onCameraReady,
      this.detector,
      this.finder,
      this.onHeavyOperationProcessing,
      this.onPictureTaken})
      : super(key: key);

  @override
  _ScanbotCameraWidgetState createState() => _ScanbotCameraWidgetState();
}

class _ScanbotCameraWidgetState extends State<ScanbotCamera> {
  ScanbotCameraController? _scanbotCameraController;

  @override
  Widget build(BuildContext context) {
    return OrientationBuilder(
      builder: (context, orientation) {
        var configuration = widget.configuration;
        var json = configuration.toJson();
        json["layout_orientation"] = orientation.name;
        if (defaultTargetPlatform == TargetPlatform.android) {
          return Stack(
            children: [
              AndroidView(
                key: Key("camera_${orientation.name}"),
                viewType: "scanbot_sdk_camera",
                layoutDirection: TextDirection.ltr,
                onPlatformViewCreated: _onPlatformViewCreated,
                creationParams: json,
                creationParamsCodec: const StandardMessageCodec(),
              ),
              (widget.finder != null)
                  ? FinderView(
                      key: Key("finder_${orientation.name}"),
                      config: widget.finder!,
                      viewId: orientation.name,
                    )
                  : Container()
            ],
          );
        }
        if (defaultTargetPlatform == TargetPlatform.iOS) {
          return Stack(
            children: [
              UiKitView(
                viewType: "scanbot_sdk_camera",
                layoutDirection: TextDirection.ltr,
                onPlatformViewCreated: _onPlatformViewCreated,
                creationParams: json,
                creationParamsCodec: const StandardMessageCodec(),
              ),
              (widget.finder != null)
                  ? FinderView(
                      config: widget.finder!,
                    )
                  : Container()
            ],
          );
        }
        return Text(
            '$defaultTargetPlatform is not yet supported by the camera plugin');
      },
    );
  }

  void _onPlatformViewCreated(int id) {
    var scanbotCameraController = ScanbotCameraController(
        viewId: id,
        onCameraReady: widget.onCameraReady,
        detector: widget.detector,
        onHeavyOperationProcessing: widget.onHeavyOperationProcessing,
        onPictureTaken: widget.onPictureTaken);
    _scanbotCameraController = scanbotCameraController;
  }

  @override
  void dispose() {
    super.dispose();
    _scanbotCameraController?._disposeCamera();
  }
}

class ScanbotCameraController {
  int viewId;
  final Function(ScanbotCameraController)? onCameraReady;

  ScanbotCameraController({
    required this.viewId,
    required this.onCameraReady,
    this.onPictureTaken,
    this.onHeavyOperationProcessing,
    this.detector,
  }) {
    cameraChannel = MethodChannel('scanbot_sdk_camera_$viewId');
    cameraChannel.setMethodCallHandler(_resultHandler);
    _onAttachDetector();
  }

  late MethodChannel cameraChannel;

  LiveDetector? detector;

  /// triggers when camera plugin make long work eg. saving snap to the image etc.
  final Function(bool)? onHeavyOperationProcessing;

  /// returns page after sucessfull snap
  final Function(c.Page)? onPictureTaken;

  void _onAttachDetector() {
    if (detector != null) {
      _attachDetector(detector!);
    }
  }

  void _attachDetector(LiveDetector detector) {
    this.detector?.attach(this);
  }

  Future<dynamic> toggleContinuosFocus() async {
    return await cameraChannel.invokeMethod("toggleContinuousFocus");
  }

  Future<bool> isFlashAvailable() async {
    return await cameraChannel.invokeMethod("isFlashAvailable");
  }

  void _disposeCamera() async {
    await cameraChannel.invokeMethod("dispose");
  }

  Future<dynamic> setFlashEnabled(bool ebabled) async {
    return await cameraChannel
        .invokeMethod("flashEnabled", {"enabled": ebabled});
  }

  Future<dynamic> _resultHandler(MethodCall methodCall) async {
    switch (methodCall.method) {
      case 'onPictureTaken':
        c.Page page = c.Page.fromJson(jsonDecode(methodCall.arguments));
        onPictureTaken?.call(page);
        break;
      case 'onCameraOpen':
        onCameraReady?.call(this);
        break;
      case 'onShowHeavyProcessing':
        onHeavyOperationProcessing?.call(methodCall.arguments as bool);
        break;
      default:
    }
    return;
  }
}

==> scanbot_sdk-2.10.0.tar.gz: lib/classical_components/classical_camera.dart <==
import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:scanbot_sdk/json/common_data.dart' as common;

import 'camera_configuration.dart';
import 'finder.dart';
import 'live_detection.dart';

class ScanbotCamera extends StatefulWidget {
  final CameraConfiguration configuration;

  final LiveDetector? detector;

  /// triggers when camera plugin make long work eg. saving snap to the image etc.
  final Function(bool)? onHeavyOperationProcessing;

  /// returns page after sucessfull snap
  final Function(common.Page)? onPictureTaken;

  final Function(ScanbotCameraController) onCameraReady;

  final FinderConfiguration? finder;

  const ScanbotCamera(
      {Key? key,
      required this.configuration,
      required this.onCameraReady,
      this.detector,
      this.finder,
      this.onHeavyOperationProcessing,
      this.onPictureTaken})
      : super(key: key);

  @override
  _ScanbotCameraWidgetState createState() => _ScanbotCameraWidgetState();
}

class _ScanbotCameraWidgetState extends State<ScanbotCamera> {
  ScanbotCameraController? _scanbotCameraController;

  @override
  Widget build(BuildContext context) {
    return OrientationBuilder(
      builder: (context, orientation) {
        var configuration = widget.configuration;
        var json = configuration.toJson();
        json["layout_orientation"] = orientation.name;
        if (defaultTargetPlatform == TargetPlatform.android) {
          return Stack(
            children: [
              AndroidView(
                key: Key("camera_${orientation.name}"),
                viewType: "scanbot_sdk_camera",
                layoutDirection: TextDirection.ltr,
                onPlatformViewCreated: _onPlatformViewCreated,
                creationParams: json,
                creationParamsCodec: const StandardMessageCodec(),
              ),
              (widget.finder != null)
                  ? FinderView(
                      key: Key("finder_${orientation.name}"),
                      config: widget.finder!,
                      viewId: orientation.name,
                    )
                  : Container()
            ],
          );
        }
        if (defaultTargetPlatform == TargetPlatform.iOS) {
          return Stack(
            children: [
              UiKitView(
                viewType: "scanbot_sdk_camera",
                layoutDirection: TextDirection.ltr,
                onPlatformViewCreated: _onPlatformViewCreated,
                creationParams: json,
                creationParamsCodec: const StandardMessageCodec(),
              ),
              (widget.finder != null)
                  ? FinderView(
                      config: widget.finder!,
                    )
                  : Container()
            ],
          );
        }
        return Text(
            '$defaultTargetPlatform is not yet supported by the camera plugin');
      },
    );
  }

  void _onPlatformViewCreated(int id) {
    var scanbotCameraController = ScanbotCameraController(
        viewId: id,
        onCameraReady: widget.onCameraReady,
        detector: widget.detector,
        onHeavyOperationProcessing: widget.onHeavyOperationProcessing,
        onPictureTaken: widget.onPictureTaken);
    _scanbotCameraController = scanbotCameraController;
  }

  @override
  void dispose() {
    super.dispose();
    _scanbotCameraController?._disposeCamera();
  }
}

class ScanbotCameraController {
  int viewId;
  late Function(ScanbotCameraController)? _onCameraReady;
  late MethodChannel _cameraChannel;

  /// triggers when camera plugin make long work eg. saving snap to the image etc.
  late Function(bool)? _onHeavyOperationProcessing;

  /// returns page after sucessfull snap
  late Function(common.Page)? _onPictureTaken;
  ScanbotCameraController({
    required this.viewId,
    required Function(ScanbotCameraController)? onCameraReady,
    Function(common.Page)? onPictureTaken,
    Function(bool)? onHeavyOperationProcessing,
    this.detector,
  }) {
    this._onHeavyOperationProcessing = onHeavyOperationProcessing;
    this._onCameraReady = onCameraReady;
    this._onPictureTaken = onPictureTaken;
    _cameraChannel = MethodChannel('scanbot_sdk_camera_$viewId');
    _cameraChannel.setMethodCallHandler(_resultHandler);
    _onAttachDetector();
  }

  LiveDetector? detector;

  void _onAttachDetector() {
    if (detector != null) {
      _attachDetector(detector!);
    }
  }

  void _attachDetector(LiveDetector detector) {
    this.detector?.attach(this);
  }

  Future<dynamic> toggleContinuosFocus() async {
    return await _cameraChannel.invokeMethod("toggleContinuousFocus");
  }

  Future<bool> isFlashAvailable() async {
    return await _cameraChannel.invokeMethod("isFlashAvailable");
  }

  void _disposeCamera() async {
    await _cameraChannel.invokeMethod("dispose");
  }

  Future<dynamic> setFlashEnabled(bool ebabled) async {
    return await _cameraChannel
        .invokeMethod("flashEnabled", {"enabled": ebabled});
  }

  Future<dynamic> _resultHandler(MethodCall methodCall) async {
    switch (methodCall.method) {
      case 'onPictureTaken':
        common.Page page =
            common.Page.fromJson(jsonDecode(methodCall.arguments));
        _onPictureTaken?.call(page);
        break;
      case 'onCameraOpen':
        _onCameraReady?.call(this);
        break;
      case 'onShowHeavyProcessing':
        _onHeavyOperationProcessing?.call(methodCall.arguments as bool);
        break;
      default:
    }
    return;
  }
}
